@@ -1,4 +1,9 @@
 use Bio::Graphics::Panel;
+use strict;
+
+use vars '$VERSION';
+$VERSION = '0.92';
+
 
 1;
 
