@@ -26,10 +26,12 @@ sub new {
   $self->{top} = 0;
 
   my @subglyphs;
+  my @subfeatures = $self->subseq($feature);
 
-  if (my @subfeatures = $self->subseq($feature)) {
-    @subglyphs = sort { $a->left  <=> $b->left }
-      $factory->make_glyph(@subfeatures);  # dynamic glyph resolution
+  if (@subfeatures) {
+    
+    # dynamic glyph resolution
+    @subglyphs = sort { $a->left  <=> $b->left }  $factory->make_glyph(@subfeatures);  
 
     $self->{parts}   = \@subglyphs;
   }
@@ -51,7 +53,6 @@ sub new {
   $self->{point} = $arg{-point} ? $self->height : undef;
   if($self->option('point')){
     my ($left,$right) = $factory->map_pt($self->start,$self->stop);
-#    my $center = int(($self->{right} + $self->{left}) / 2);
     my $center = int(($left+$right)/2);
 
     $self->{width} = $self->height;
@@ -168,8 +169,8 @@ sub layout_width {
 
 # returns the rectangle that surrounds the physical part of the
 # glyph, excluding labels and other "extra" stuff
-sub calculate_boundaries {return shift->bounds(@_);}#is this right?
-                                                    #should be gd->getBounds()?
+sub calculate_boundaries {return shift->bounds(@_);}
+
 sub bounds {
   my $self = shift;
   my ($dx,$dy) = @_;
@@ -179,6 +180,7 @@ sub bounds {
    $dx + $self->{left} + $self->{width} -1,
    $dy + $self->bottom - $self->pad_bottom);
 }
+
 sub box {
   my $self = shift;
   my $gd = shift;
@@ -317,6 +319,12 @@ sub fgcolor {
   $self->factory->translate_color($index);
 }
 
+#add for compatibility
+sub fillcolor {
+    my $self = shift;
+    return $self->bgcolor;
+}
+
 # we also look for the "background-color" option for Ace::Graphics compatibility
 sub bgcolor {
   my $self = shift;
@@ -509,12 +517,12 @@ sub draw_hat_connector {
     return;
   }
 
-  if ($right - $left > 3) {  # room for the inverted "V"
-      my $middle = $left + ($right - $left)/2;
+  if ($right - $left > 4) {  # room for the inverted "V"
+      my $middle = $left + int(($right - $left)/2);
       $gd->line($left,$center1,$middle,$top1,$color);
-      $gd->line($middle,$top1,$right,$center1,$color);
+      $gd->line($middle,$top1,$right-1,$center1,$color);
     } elsif ($right-$left > 1) { # no room, just connect
-      $gd->line($left,$quarter1,$right,$quarter1,$color);
+      $gd->line($left,$quarter1,$right-1,$quarter1,$color);
     }
 
 }
@@ -697,15 +705,13 @@ sub keyglyph {
 
   my $scale = 1/$self->scale;  # base pairs/pixel
 
-  # two segments, at pixels 0->50, 60->80
+  # one segments, at pixels 0->80
   my $offset = $self->panel->offset;
 
 
   my $feature =
-    Bio::Graphics::Feature->new(
-				-segments=>[ [ 0*$scale +$offset,50*$scale+$offset],
-					     [60*$scale+$offset, 80*$scale+$offset]
-					   ],
+    Bio::Graphics::Feature->new(-start =>0 * $scale +$offset,
+				-end   =>80*$scale+$offset,
 				-name => $self->option('key'),
 				-strand => '+1');
   my $factory = $self->factory->clone;
@@ -1105,7 +1111,11 @@ L<Bio::Graphics::Glyph::box>,
 L<Bio::Graphics::Glyph::primers>,
 L<Bio::Graphics::Glyph::segments>,
 L<Bio::Graphics::Glyph::toomany>,
+L<Bio::Graphics::Glyph::triangle>,
+L<Bio::Graphics::Glyph::diamond>,
 L<Bio::Graphics::Glyph::transcript>,
+L<Bio::Graphics::Glyph::transcript2>,
+L<Bio::Graphics::Glyph::wormbase_transcript>
 
 =head1 AUTHOR
 
