@@ -6,6 +6,10 @@ use vars '@ISA';
 use Bio::Graphics::Glyph::generic;
 @ISA = 'Bio::Graphics::Glyph::generic';
 
+my %UNITS = (K => 1000,
+	     M => 1_000_000,
+	     G => 1_000_000_000);
+
 sub pad_bottom {
   my $self = shift;
   my $val = $self->SUPER::pad_bottom(@_);
@@ -88,7 +92,10 @@ sub draw_parallel {
     my $offset   = $relative ? $self->feature->start-1 : 0;
     my $reversed = $self->feature->strand < 0;
 
-    my ($major_ticks,$minor_ticks) = $self->panel->ticks($start,$stop,$font);
+    my $units = $self->option('units') || '';
+    my $divisor = $UNITS{$units} || 1 if $units;
+
+    my ($major_ticks,$minor_ticks) = $self->panel->ticks($start,$stop,$font,$divisor);
 
     ## Does the user want to override the internal scale?
     my $scale = $self->option('scale');
@@ -96,13 +103,19 @@ sub draw_parallel {
     my $left  = $sw ? $x1+$height : $x1;
     my $right = $ne ? $x2-$height : $x2;
 
+    my $format = ($major_ticks->[1]-$major_ticks->[0])/($divisor||1) < 1 ? "%.1f$units" : "%d$units";
+
     for my $i (@$major_ticks) {
       my $tickpos = $dx + ($reversed ? $self->map_pt($stop - $i + $offset)
 	                             : $self->map_pt($i + $offset));
       next if $tickpos < $left or $tickpos > $right;
       $gd->line($tickpos,$center-$a2,$tickpos,$center+$a2,$fg);
-      my $middle = $tickpos - (length($i) * $width)/2;
       my $label = $scale ? $i / $scale : $i;
+      if ($units) {
+	my $scaled = $label/$divisor;
+	$label = sprintf($format,$scaled);
+      }
+      my $middle = $tickpos - (length($label) * $width)/2;
       $gd->string($font,$middle,$center+$a2-1,$label,$font_color);
     }
 
