@@ -2,8 +2,8 @@ package Bio::Graphics::Glyph::group;
 
 use strict;
 use vars '@ISA';
-use Bio::Graphics::Glyph::generic;
-@ISA = 'Bio::Graphics::Glyph::generic';
+use Bio::Graphics::Glyph::segmented_keyglyph;
+@ISA = 'Bio::Graphics::Glyph::segmented_keyglyph';
 
 # group sets connector to 'dashed'
 sub connector {
